@@ -8,10 +8,10 @@
 */
 
 #include "feed.h"
-
 #include "akregatorconfig.h"
 #include "article.h"
 #include "articlejobs.h"
+#include "config-akregator.h"
 #include "feedretriever.h"
 #include "fetchqueue.h"
 #include "folder.h"
@@ -97,6 +97,8 @@ public:
     Feed::ImageInfo m_faviconInfo;
 
     QIcon m_favicon;
+    QStringList m_activities;
+    bool m_activityEnabled = false;
     mutable int m_totalCount;
     void setTotalCountDirty() const;
 };
@@ -190,6 +192,12 @@ Akregator::Feed *Feed::fromOPML(const QDomElement &e, Backend::Storage *storage)
         feed->d->m_archive = storage->archiveFor(xmlUrl);
         feed->d->m_totalCount = feed->d->m_archive->totalCount();
     }
+
+#if HAVE_ACTIVITY_SUPPORT
+    feed->setActivityEnabled(e.attribute(QStringLiteral("activityEnabled")) == QLatin1StringView("true"));
+    feed->setActivities(e.attribute(QStringLiteral("activities")).split(QLatin1Char(';')));
+#endif
+
     return feed;
 }
 
@@ -274,7 +282,7 @@ void Feed::recalcUnreadCount()
     QList<Article>::ConstIterator it;
     QList<Article>::ConstIterator en = tarticles.constEnd();
 
-    int oldUnread = d->m_archive->unread();
+    const int oldUnread = d->m_archive->unread();
 
     int unread = 0;
 
@@ -349,7 +357,7 @@ Feed::~Feed()
 
 void Feed::loadFavicon(const QString &url, bool downloadFavicon)
 {
-    QUrl u(url);
+    const QUrl u(url);
     if (u.scheme().isEmpty()) {
         qCWarning(AKREGATOR_LOG) << "Invalid url" << url;
     }
@@ -463,6 +471,26 @@ QString Feed::xmlUrl() const
     return d->m_xmlUrl;
 }
 
+QStringList Feed::activities() const
+{
+    return d->m_activities;
+}
+
+void Feed::setActivities(const QStringList &lst)
+{
+    d->m_activities = lst;
+}
+
+bool Feed::activityEnabled() const
+{
+    return d->m_activityEnabled;
+}
+
+void Feed::setActivityEnabled(bool b)
+{
+    d->m_activityEnabled = b;
+}
+
 void Feed::setXmlUrl(const QString &s)
 {
     d->m_xmlUrl = s;
@@ -498,7 +526,7 @@ void Feed::setFaviconLocalPath(const QString &localPath)
 void Feed::setFaviconInfo(const Feed::ImageInfo &info)
 {
     d->m_faviconInfo = info;
-    QUrl u(info.imageUrl);
+    const QUrl u(info.imageUrl);
     if (u.isLocalFile()) {
         setFavicon(QIcon(u.toLocalFile()));
     }
@@ -574,6 +602,12 @@ QDomElement Feed::toOPML(QDomElement parent, QDomDocument document) const
         }
     }
     el.setAttribute(QStringLiteral("maxArticleNumber"), d->m_maxArticleNumber);
+#if HAVE_ACTIVITY_SUPPORT
+    if (d->m_activityEnabled) {
+        el.setAttribute(QStringLiteral("activityEnabled"), QStringLiteral("true"));
+    }
+    el.setAttribute(QStringLiteral("activities"), d->m_activities.join(QLatin1Char(',')));
+#endif
     el.setAttribute(QStringLiteral("type"), QStringLiteral("rss")); // despite some additional fields, it is still "rss" OPML
     el.setAttribute(QStringLiteral("version"), QStringLiteral("RSS"));
     parent.appendChild(el);
@@ -706,12 +740,14 @@ bool Feed::isExpired(const Article &a) const
     const QDateTime now = QDateTime::currentDateTime();
     int expiryAge = -1;
     // check whether the feed uses the global default and the default is limitArticleAge
+    constexpr int time = 24 * 3600;
     if (d->m_archiveMode == globalDefault && Settings::archiveMode() == Settings::EnumArchiveMode::limitArticleAge) {
-        expiryAge = Settings::maxArticleAge() * 24 * 3600;
-    } else // otherwise check if this feed has limitArticleAge set
+        expiryAge = Settings::maxArticleAge() * time;
+    } else { // otherwise check if this feed has limitArticleAge set
         if (d->m_archiveMode == limitArticleAge) {
-            expiryAge = d->m_maxArticleAge * 24 * 3600;
+            expiryAge = d->m_maxArticleAge * time;
         }
+    }
 
     return expiryAge != -1 && a.pubDate().secsTo(now) > expiryAge;
 }
