@@ -8,20 +8,29 @@
 
 #pragma once
 
+#include "config-akregator.h"
 #include "feed.h"
 #include "ui_feedpropertieswidgetbase.h"
-
 #include <QDialog>
 
 #include <QWidget>
+#if HAVE_ACTIVITY_SUPPORT
+#include "activities/activitiesmanager.h"
+#endif
 
+#if HAVE_ACTIVITY_SUPPORT
+namespace PimCommonActivities
+{
+class ConfigureActivitiesWidget;
+}
+#endif
 namespace Akregator
 {
 class FeedPropertiesWidget : public QWidget, public Ui::FeedPropertiesWidgetBase
 {
     Q_OBJECT
 public:
-    explicit FeedPropertiesWidget(QWidget *parent = nullptr, const QString &name = QString());
+    explicit FeedPropertiesWidget(QWidget *parent = nullptr);
     ~FeedPropertiesWidget() override;
 
     enum IntervalStep {
@@ -31,10 +40,20 @@ public:
         Never,
     };
 
-public Q_SLOTS:
+#if HAVE_ACTIVITY_SUPPORT
+    [[nodiscard]] PimCommonActivities::ConfigureActivitiesWidget *configureActivitiesWidget() const;
+    [[nodiscard]] ActivitiesManager::ActivitySettings activitySettings() const;
+    void setActivitiesSettings(const ActivitiesManager::ActivitySettings &activitySettings);
+#endif
+
+private:
     void slotUpdateComboBoxActivated(int index);
     void slotUpdateComboBoxLabels(int value);
     void slotUpdateCheckBoxToggled(bool enabled);
+
+#if HAVE_ACTIVITY_SUPPORT
+    PimCommonActivities::ConfigureActivitiesWidget *const mConfigureActivitiesWidget;
+#endif
 };
 
 class FeedPropertiesDialog : public QDialog
@@ -54,6 +73,11 @@ public Q_SLOTS:
     void accept() override;
 
 protected:
+#if HAVE_ACTIVITY_SUPPORT
+    void setActivitiesSettings(const ActivitiesManager::ActivitySettings &activitySettings);
+    [[nodiscard]] ActivitiesManager::ActivitySettings activitySettings() const;
+#endif
+
     [[nodiscard]] QString comment() const;
     [[nodiscard]] QString feedName() const;
     [[nodiscard]] QString url() const;
@@ -80,7 +104,7 @@ protected:
     void setComment(const QString &comment);
 
 private:
-    FeedPropertiesWidget *widget = nullptr;
+    FeedPropertiesWidget *const mFeedPropertiesWidget;
     Feed *m_feed = nullptr;
     QPushButton *mOkButton = nullptr;
 
