@@ -32,8 +32,8 @@ SearchBar::SearchBar(QWidget *parent)
     : QWidget(parent)
     , m_searchLine(new StatusSearchLine(this))
     , m_statusSearchButtons(new StatusSearchButtons(this))
+    , m_delay(400)
 {
-    m_delay = 400;
     auto layout = new QHBoxLayout(this);
 
     layout->setContentsMargins({});
@@ -83,16 +83,6 @@ StatusSearchButtons::Status SearchBar::status() const
     return m_statusSearchButtons->status();
 }
 
-void SearchBar::setDelay(int ms)
-{
-    m_delay = ms;
-}
-
-int SearchBar::delay() const
-{
-    return m_delay;
-}
-
 void SearchBar::setFocusSearchLine()
 {
     m_searchLine->setFocus();
